# nf-launcher

## Description
 - Install Nextflow launcher using `pip install nf-launcher`. 
 - Now `nextflow` command is available on your path.
 - Run `nextflow info` to force it download all the dependencies (optional).
 - Now you are ready to run a pipeline `nextflow run hello`. 

## Requirements
The Nextflow launcher requires Java and curl or wget available on your
system to be able to download Nextflow java dependencies and launch Nextflow